==> portal-contribuinte-3.081.2.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/find-debitos-de-pagamento-negociado.sql <==
SELECT td.entidade,
              td.tipocadastro,
              td.cadastrogeral,
              td.exercicio,
              td.guiarecolhimento as divida,
              td.subdivida,
              tdpr.parcela,
              tdp.datavencimento,
              tdp.datalancamento ,
              td.dataprimeiraparcela ,
              td.formacorrecao ,
              td.parcelado ,
              td.reparcelado ,
              tdp.idprotesto ,
              td.idparcelamento ,
              tsp.descricao as situacaodebitodescricao,
              td.iddebito,
              tsp.tiposituacaoparcela,
              tdp.situacaolegal,
              tdpr.receita as tributo,
              tdpr.valor AS valorprincipal,
              tdpr.iddebitoparcelareceita
FROM tribdebito td
INNER JOIN tribdebitoparcelareceita tdpr ON tdpr.entidade = td.entidade
				        AND tdpr.exercicio = td.exercicio
					AND tdpr.tipocadastro = td.tipocadastro
					AND tdpr.cadastrogeral = td.cadastrogeral
					AND tdpr.guiarecolhimento = td.guiarecolhimento
					AND tdpr.subdivida = td.subdivida
INNER JOIN tribdebitoparcela tdp ON tdpr.entidade = tdp.entidade
				AND tdpr.exercicio = tdp.exercicio
				AND tdpr.tipocadastro = tdp.tipocadastro
				AND tdpr.cadastrogeral = tdp.cadastrogeral
				AND tdpr.guiarecolhimento = tdp.guiarecolhimento
				AND tdpr.subdivida = tdp.subdivida
				AND tdpr.parcela = tdp.parcela
LEFT OUTER JOIN tribsituacaoparcela tsp ON tdp.situacaodebito = tsp.situacaoparcela
LEFT OUTER join tribtiposituacaoparcela ttsp on tsp.tiposituacaoparcela  = ttsp.tiposituacaoparcela
WHERE td.entidade = :ENTIDADEPRINCIPAL
  AND tdp.situacaodebito = 1
  AND td.parcelado = 'N'
  AND td.reparcelado = 'N'
  AND ttsp.tipo = 'A'
  :Filtros

==> portal-contribuinte-4.106.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/find-debitos-de-pagamento-negociado.sql <==
SELECT td.entidade,
              td.tipocadastro,
              td.cadastrogeral,
              td.exercicio,
              td.guiarecolhimento as divida,
              td.subdivida,
              tdpr.parcela,
              tdp.datavencimento,
              tdp.datalancamento ,
              td.dataprimeiraparcela ,
              td.datacorrecaoigpm,
              td.formacorrecao ,
              case when td.parcelado = 'S' then 1 else 0 end as parcelado,
              case when td.reparcelado = 'S' then 1 else 0 end as reparcelado,
              tdp.idprotesto ,
              td.idparcelamento ,
              tsp.descricao as situacaodebitodescricao,
              td.iddebito,
              tsp.tiposituacaoparcela,
              tdp.situacaolegal,
              tdpr.receita as tributo,
              tdpr.valor AS valorprincipal,
              tdpr.iddebitoparcelareceita
FROM tribdebito td
INNER JOIN tribdebitoparcelareceita tdpr ON tdpr.entidade = td.entidade
				        AND tdpr.exercicio = td.exercicio
					AND tdpr.tipocadastro = td.tipocadastro
					AND tdpr.cadastrogeral = td.cadastrogeral
					AND tdpr.guiarecolhimento = td.guiarecolhimento
					AND tdpr.subdivida = td.subdivida
INNER JOIN tribdebitoparcela tdp ON tdpr.entidade = tdp.entidade
				AND tdpr.exercicio = tdp.exercicio
				AND tdpr.tipocadastro = tdp.tipocadastro
				AND tdpr.cadastrogeral = tdp.cadastrogeral
				AND tdpr.guiarecolhimento = tdp.guiarecolhimento
				AND tdpr.subdivida = tdp.subdivida
				AND tdpr.parcela = tdp.parcela
LEFT OUTER JOIN tribsituacaoparcela tsp ON tdp.situacaodebito = tsp.situacaoparcela
LEFT OUTER join tribtiposituacaoparcela ttsp on tsp.tiposituacaoparcela  = ttsp.tiposituacaoparcela
left join tribparcelamentodebito tpd on td.iddebito = tpd.iddebito
left join tribparcelamento tp on tpd.idparcelamento = tp.idparcelamento
WHERE td.entidade = :ENTIDADEPRINCIPAL
  AND tdp.situacaodebito = 1
  AND ttsp.tipo = 'A'
  :Filtros
